@@ -150,7 +150,6 @@ DocumentPtr create_document(const file_record& record) {
 
 
 #define INDEX_VERSION L"2"
-#define INVALID_INDEX_VERSION L"0"
 #define INDEX_VERSION_FIELD L"index_version"
 
 file_index_manager::file_index_manager(const std::string& persistent_index_dir,
@@ -212,40 +211,55 @@ file_index_manager::~file_index_manager() {
     }
 }
 
-void file_index_manager::add_index(const std::string& path) {
+bool file_index_manager::add_index(const std::string& path) {
+    bool ret = false;
+
     try {
         auto doc = create_document(make_file_record(path, pinyin_processor_, file_type_mapping_));
         writer_->updateDocument(newLucene<Term>(FULL_PATH_FIELD, StringUtils::toUnicode(path)), doc);
         spdlog::debug("Indexed {}", path);
+        ret = true;
     } catch (const LuceneException& e) {
         spdlog::error("Failed to index {}: {}", path, StringUtils::toUTF8(e.getError()));
     } catch (const std::exception& e) {
         spdlog::error("Failed to index {}: {}", path, e.what());
     }
+
+    return ret;
 }
 
-void file_index_manager::remove_index(const std::string& path) {
+bool file_index_manager::remove_index(const std::string& path) {
+    bool ret = false;
+
     try {
         TermPtr pterm = newLucene<Term>(FULL_PATH_FIELD, StringUtils::toUnicode(path));
         writer_->deleteDocuments(pterm);
         spdlog::debug("Removed index: {}", path);
+        ret = true;
     } catch (const LuceneException& e) {
         spdlog::error("Failed to remove index {}: {}", path, StringUtils::toUTF8(e.getError()));
     } catch (const std::exception& e) {
         spdlog::error("Failed to remove index {}: {}", path, e.what());
     }
+
+    return ret;
 }
 
-void file_index_manager::update_index(const std::string& old_path, const std::string& new_path) {
+bool file_index_manager::update_index(const std::string& old_path, const std::string& new_path) {
+    bool ret = false;
+
     try {
         auto doc = create_document(make_file_record(new_path, pinyin_processor_, file_type_mapping_));
         writer_->updateDocument(newLucene<Term>(FULL_PATH_FIELD, StringUtils::toUnicode(old_path)), doc);
         spdlog::debug("Renamed: {} --> {}", old_path, new_path);
+        ret = true;
     } catch (const LuceneException& e) {
         spdlog::error("Failed to rename index {} to {}: {}", old_path, new_path, StringUtils::toUTF8(e.getError()));
     } catch (const std::exception& e) {
         spdlog::error("Failed to rename index {} to {}: {}", old_path, new_path, e.what());
     }
+
+    return ret;
 }
 
 bool check_index_corrupted(const std::string& index_directory) {
@@ -328,8 +342,11 @@ std::string file_index_manager::index_directory() const {
     return persistent_index_directory_;
 }
 
-std::vector<std::string> file_index_manager::traverse_directory(const std::string& path, bool nrt) {
+std::vector<std::string> file_index_manager::traverse_directory(const std::string& path, bool nrt, bool &success) {
+    success = false;
+
     if (path.empty()) {
+        success = true;
         return {};
     }
 
@@ -363,9 +380,11 @@ std::vector<std::string> file_index_manager::traverse_directory(const std::strin
             results.push_back(StringUtils::toUTF8(doc->get(FULL_PATH_FIELD)));
         }
 
+        success = true;
         return results;
     } catch (const LuceneException& e) {
         spdlog::error("Failed to traverse directory {}: {}", path, StringUtils::toUTF8(e.getError()));
+        success = false;
         return {};
     }
 }
@@ -424,13 +443,8 @@ bool file_index_manager::refresh_indexes(const std::vector<std::string>& blackli
 void file_index_manager::set_index_invalid()
 {
     try {
-        set_index_version();
-
-        DocumentPtr doc = newLucene<Document>();
-        doc->add(newLucene<Field>(INDEX_VERSION_FIELD, INVALID_INDEX_VERSION, Field::STORE_YES, Field::INDEX_NOT_ANALYZED));
-        writer_->updateDocument(newLucene<Term>(INDEX_VERSION_FIELD, INDEX_VERSION), doc);
-    } catch (const LuceneException& e) {
-        spdlog::error("Failed to set index invalid: {}", StringUtils::toUTF8(e.getError()));
+        std::ofstream invalid_index_file(volatile_index_directory_ + "/invalid_index");
+        invalid_index_file.close();
     } catch (const std::exception& e) {
         spdlog::error("Failed to set index invalid: {}", e.what());
     }
@@ -498,6 +512,13 @@ void file_index_manager::check_index_version() {
         return;
     }
 
+    // 检查是否是无效索引
+    if (std::filesystem::exists(volatile_index_directory_ + "/invalid_index", ec)) {
+        spdlog::warn("The index is invalid: {}, remove it", volatile_index_directory_);
+        std::filesystem::remove_all(volatile_index_directory_);
+        return;
+    }
+
     // 打开索引
     try {
         FSDirectoryPtr dir = FSDirectory::open(StringUtils::toUnicode(volatile_index_directory_));
